from setuptools import setup, find_packages



setup(
    name = 'basicreadme',
    version = '1.0.0',
    description = 'basic',
    long_description=open('README.txt').read(),
    url='',
    author='saurabh',
    license='MIT',
    keywords='',
    packages=find_packages(),
)